@@ -3,7 +3,7 @@ from __future__ import unicode_literals, absolute_import
 from bizerror.base import BizErrorBase
 from bizerror.base import set_error_info
 
-# Created: 2021-02-19 14:12:15.556000
+# Created: 2021-02-20 14:20:38.249000
 # WARNING! All changes made in this file will be lost!
 
 
@@ -62,6 +62,11 @@ class NotSupportedHttpMethod(HttpError):
 set_error_info("en", "NotSupportedHttpMethod", 1001010002, "Not supported http method.")
 set_error_info("zh-hans", "NotSupportedHttpMethod", 1001010002, "不支持的请求方法！")
 
+class BadResponseContent(HttpError):
+    pass
+set_error_info("en", "BadResponseContent", 1001010003, "Bad response content. Content returned: {content}.")
+set_error_info("zh-hans", "BadResponseContent", 1001010003, "HTTP接口响应内容格式非法，响应报文内容为{content}。")
+
 class ConfigError(BizErrorBase):
     pass
 set_error_info("en", "ConfigError", 1001020000, "Config error.")
@@ -179,8 +184,8 @@ set_error_info("zh-hans", "CastToStringFailed", 1001050005, "字段{field}转化
 
 class ParseJsonError(TypeError):
     pass
-set_error_info("en", "ParseJsonError", 1001050006, "Parse json error.")
-set_error_info("zh-hans", "ParseJsonError", 1001050006, "Json转化异常！")
+set_error_info("en", "ParseJsonError", 1001050006, "Parse json error. Raw text {text}.")
+set_error_info("zh-hans", "ParseJsonError", 1001050006, "Json转化异常！原始报文内容{text}。")
 
 class NotSupportedTypeToCast(TypeError):
     pass
